"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFadeTransition = void 0;

var _react = _interopRequireDefault(require("react"));

var _reactNative = require("react-native");

var _canUseDom = require("../../../utils/canUseDom");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const useFadeTransition = (duration = 500, initValue = 0, finalValue = 1) => {
  const isDomUsable = (0, _canUseDom.canUseDom)();

  const fadeValue = _react.default.useRef(new _reactNative.Animated.Value(0)).current;

  const fadeIn = () => {
    if (isDomUsable) {
      _reactNative.Animated.timing(fadeValue, {
        toValue: finalValue,
        duration: duration,
        useNativeDriver: _reactNative.Platform.OS !== 'web'
      }).start();
    }
  };

  const fadeOut = () => {
    if (isDomUsable) {
      _reactNative.Animated.timing(fadeValue, {
        toValue: initValue,
        duration: duration,
        useNativeDriver: _reactNative.Platform.OS !== 'web'
      }).start();
    }
  };

  return {
    fadeValue,
    fadeIn,
    fadeOut
  };
};

exports.useFadeTransition = useFadeTransition;
//# sourceMappingURL=useFadeTransition.js.map