"use strict";

var _react = _interopRequireDefault(require("react"));

var _utils = require("../useThemeProps/utils");

var _NativeBaseProvider = require("../../core/NativeBaseProvider");

var _theme = require("../../theme");

var _reactHooks = require("@testing-library/react-hooks");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('useCalculateProps', () => {
  const wrapper = ({
    children
  }) => /*#__PURE__*/_react.default.createElement(_NativeBaseProvider.NativeBaseProvider, {
    initialWindowMetrics: {
      frame: {
        x: 0,
        y: 0,
        width: 0,
        height: 0
      },
      insets: {
        top: 0,
        left: 0,
        right: 0,
        bottom: 0
      }
    }
  }, children);

  const colorModeProps = {
    colorMode: 'light',
    toggleColorMode: () => {},
    setColorMode: () => {}
  };
  test('No component theme + no props', () => {
    const {
      result
    } = (0, _reactHooks.renderHook)(() => (0, _utils.calculateProps)(_theme.theme, colorModeProps, {}, {}, 750), {
      wrapper
    });
    expect(result.current).toEqual({});
  });
  test('Only component theme(Badge) + no props', () => {
    const componentTheme = _theme.theme.components.Badge;
    const {
      result
    } = (0, _reactHooks.renderHook)(() => (0, _utils.calculateProps)(_theme.theme, colorModeProps, componentTheme, {}, 750), {
      wrapper
    });
    expect(result.current).toEqual({
      _text: {
        color: 'gray.700',
        fontSize: 'xs',
        fontWeight: 'bold',
        textTransform: 'uppercase'
      },
      px: 1,
      py: 1,
      borderRadius: 'lg',
      bg: 'gray.100',
      borderWidth: 1,
      borderColor: 'transparent'
    });
  });
  test('Component theme(Badge) + some props', () => {
    const componentTheme = _theme.theme.components.Badge;
    const {
      result
    } = (0, _reactHooks.renderHook)(() => (0, _utils.calculateProps)(_theme.theme, colorModeProps, componentTheme, {
      py: 3
    }, 750), {
      wrapper
    });
    expect(result.current).toEqual({
      _text: {
        color: 'gray.700',
        fontSize: 'xs',
        fontWeight: 'bold',
        textTransform: 'uppercase'
      },
      px: 1,
      py: 3,
      borderRadius: 'lg',
      bg: 'gray.100',
      borderWidth: 1,
      borderColor: 'transparent'
    });
  });
});
//# sourceMappingURL=calculateProps.test.js.map