"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useContrastText = useContrastText;

var _tinycolor = _interopRequireDefault(require("tinycolor2"));

var _useToken = require("./../../hooks/useToken");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function useContrastText(bg, color) {
  let [contrastThreshold, trueDarkText, trueLightText, trueBg, trueColor] = (0, _useToken.useToken)('colors', ['contrastThreshold', 'darkText', 'lightText', bg, color !== null && color !== void 0 ? color : '']);

  if (typeof trueBg !== 'string') {
    trueBg = bg;
  }

  const trueContrastColor = getContrastRatio(trueBg, trueDarkText) >= contrastThreshold ? trueDarkText : trueLightText;
  const contrastColorToken = getContrastRatio(trueBg, trueDarkText) >= contrastThreshold ? 'darkText' : 'lightText';

  if (process.env.NODE_ENV !== 'production') {
    const contrast = getContrastRatio(trueBg, trueColor ? trueColor : trueContrastColor);

    if (contrast < 3) {
      console.warn(["NativeBase: The contrast ratio of ".concat(contrast, ":1 for ").concat(color ? color : contrastColorToken, " on ").concat(bg), 'falls below the WCAG recommended absolute minimum contrast ratio of 3:1.', 'https://www.w3.org/TR/2008/REC-WCAG20-20081211/#visual-audio-contrast-contrast'].join('\n'));
    }
  }

  return contrastColorToken;
}

function getContrastRatio(foreground, background) {
  const lumA = (0, _tinycolor.default)(foreground).getLuminance();
  const lumB = (0, _tinycolor.default)(background).getLuminance();
  return (Math.max(lumA, lumB) + 0.05) / (Math.min(lumA, lumB) + 0.05);
}
//# sourceMappingURL=useContrastText.js.map